# Update TOML

Simple CLI to update a value in a TOML file.

## Installation

Install with pip:

```bash
pip install update-toml
```

## Usage

Run the following command, passing in a path and value to update in the specified .toml file:

```bash
update-toml --path project.version --value 0.0.1 --file pyproject.toml
```
